@@ -19,6 +19,7 @@ except ImportError:
     import mock
     from unipath import Path
 
+
 def read_file(path):
     path = str(Path(__file__, '..', 'resources', path).resolve())
 
@@ -763,7 +764,9 @@ class ClassLoaderTest(unittest.TestCase):
         everything is ok?
         """
         loader = ClassLoader()
-        cls = loader.load('stack_watcher.test.test_main.Quest')
+        cls = loader.load_question_class(
+            'stack_watcher.test.test_main.Quest',
+        )
         self.assertEqual(cls.__name__, 'Quest')
 
     def test_load_retriever_class_subclass_exception(self):
@@ -787,7 +790,9 @@ class ClassLoaderTest(unittest.TestCase):
         everything is ok?
         """
         loader = ClassLoader()
-        cls = loader.load('stack_watcher.test.test_main.SubRetriever')
+        cls = loader.load_retriever_class(
+            'stack_watcher.test.test_main.SubRetriever',
+        )
         self.assertEqual(cls.__name__, 'SubRetriever')
 
     def test_load_notifier_class_subclass_exception(self):
@@ -811,5 +816,7 @@ class ClassLoaderTest(unittest.TestCase):
         everything is ok?
         """
         loader = ClassLoader()
-        cls = loader.load('stack_watcher.test.test_main.SubNotifier')
+        cls = loader.load_notifier_class(
+            'stack_watcher.test.test_main.SubNotifier',
+        )
         self.assertEqual(cls.__name__, 'SubNotifier')
